import { resolveDirective as _resolveDirective, createVNode as _createVNode } from "vue";
// Styles
import "./VBanner.css"; // Components

import { VAvatar } from "../VAvatar/index.mjs";
import { VBannerActions } from "./VBannerActions.mjs";
import { VBannerText } from "./VBannerText.mjs";
import { VDefaultsProvider } from "../VDefaultsProvider/index.mjs"; // Composables

import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeDensityProps, useDensity } from "../../composables/density.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { makeRoundedProps, useRounded } from "../../composables/rounded.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { makeThemeProps, provideTheme } from "../../composables/theme.mjs";
import { useDisplay } from "../../composables/display.mjs"; // Utilities

import { defineComponent, useRender } from "../../util/index.mjs"; // Types

export const VBanner = defineComponent({
  name: 'VBanner',
  props: {
    avatar: String,
    color: String,
    icon: String,
    lines: String,
    sticky: Boolean,
    text: String,
    ...makeBorderProps(),
    ...makeDensityProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makePositionProps(),
    ...makeRoundedProps(),
    ...makeTagProps(),
    ...makeThemeProps()
  },

  setup(props, _ref) {
    let {
      slots
    } = _ref;
    const {
      themeClasses
    } = provideTheme(props);
    const {
      borderClasses
    } = useBorder(props);
    const {
      densityClasses
    } = useDensity(props);
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      mobile
    } = useDisplay();
    const {
      elevationClasses
    } = useElevation(props);
    const {
      positionClasses,
      positionStyles
    } = usePosition(props);
    const {
      roundedClasses
    } = useRounded(props);
    useRender(() => {
      var _slots$default;

      const hasAvatar = !!(props.avatar || props.icon || slots.avatar || slots.icon);
      const hasText = !!(props.text || slots.text);
      const hasContent = hasAvatar || hasText || slots.default;
      return _createVNode(props.tag, {
        "class": ['v-banner', {
          'v-banner--mobile': mobile.value,
          'v-banner--sticky': props.sticky,
          [`v-banner--${props.lines}-line`]: true
        }, borderClasses.value, densityClasses.value, elevationClasses.value, positionClasses.value, roundedClasses.value, themeClasses.value],
        "style": [dimensionStyles.value, positionStyles.value],
        "role": "banner"
      }, {
        default: () => [hasContent && _createVNode("div", {
          "class": "v-banner__content"
        }, [hasAvatar && _createVNode(VDefaultsProvider, {
          "defaults": {
            VAvatar: {
              color: props.color,
              density: props.density,
              icon: props.icon,
              image: props.avatar
            }
          }
        }, {
          default: () => [_createVNode("div", {
            "class": "v-banner__avatar"
          }, [slots.avatar ? slots.avatar() : _createVNode(VAvatar, null, null)])]
        }), hasText && _createVNode(VBannerText, null, {
          default: () => [slots.text ? slots.text() : props.text]
        }), (_slots$default = slots.default) == null ? void 0 : _slots$default.call(slots)]), slots.actions && _createVNode(VDefaultsProvider, {
          "defaults": {
            VBtn: {
              color: props.color,
              density: props.density,
              variant: 'text'
            }
          }
        }, {
          default: () => [_createVNode(VBannerActions, null, {
            default: slots.actions
          })]
        })]
      });
    });
  }

});
//# sourceMappingURL=VBanner.mjs.map