import { withDirectives as _withDirectives, vShow as _vShow, createVNode as _createVNode } from "vue";
// Styles
import "./VSnackbar.css"; // Components

import { VDefaultsProvider } from "../VDefaultsProvider/index.mjs"; // Composables

import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { useProxiedModel } from "../../composables/proxiedModel.mjs";
import { makeTransitionProps, MaybeTransition } from "../../composables/transition.mjs";
import { genOverlays, makeVariantProps, useVariant } from "../../composables/variant.mjs"; // Utilities

import { onMounted, watch } from 'vue';
import { defineComponent, useRender } from "../../util/index.mjs";
export const VSnackbar = defineComponent({
  name: 'VSnackbar',
  props: {
    app: Boolean,
    centered: Boolean,
    contentClass: {
      type: String,
      default: ''
    },
    multiLine: Boolean,
    timeout: {
      type: [Number, String],
      default: 5000
    },
    vertical: Boolean,
    modelValue: Boolean,
    ...makePositionProps(),
    ...makeVariantProps(),
    ...makeTransitionProps({
      transition: 'v-snackbar-transition'
    })
  },
  emits: {
    'update:modelValue': v => true
  },

  setup(props, _ref) {
    let {
      slots
    } = _ref;
    const isActive = useProxiedModel(props, 'modelValue');
    const {
      positionClasses,
      positionStyles
    } = usePosition(props);
    const {
      colorClasses,
      colorStyles,
      variantClasses
    } = useVariant(props);
    watch(isActive, startTimeout);
    watch(() => props.timeout, startTimeout);
    onMounted(() => {
      if (isActive.value) startTimeout();
    });
    let activeTimeout = -1;

    function startTimeout() {
      window.clearTimeout(activeTimeout);
      const timeout = Number(props.timeout);
      if (!isActive.value || timeout === -1) return;
      activeTimeout = window.setTimeout(() => {
        isActive.value = false;
      }, timeout);
    }

    function onPointerenter() {
      window.clearTimeout(activeTimeout);
    }

    useRender(() => {
      var _slots$default, _slots$actions;

      return _createVNode("div", {
        "class": ['v-snackbar', {
          'v-snackbar--active': isActive.value,
          'v-snackbar--bottom': props.bottom || !props.top,
          'v-snackbar--centered': props.centered,
          'v-snackbar--end': props.right,
          'v-snackbar--multi-line': props.multiLine && !props.vertical,
          'v-snackbar--start': props.left,
          'v-snackbar--top': props.top,
          'v-snackbar--vertical': props.vertical
        }, positionClasses.value],
        "style": [colorStyles.value, positionStyles.value]
      }, [_createVNode(MaybeTransition, {
        "transition": props.transition
      }, {
        default: () => [_withDirectives(_createVNode("div", {
          "class": ['v-snackbar__wrapper', colorClasses.value, variantClasses.value],
          "onPointerenter": onPointerenter,
          "onPointerleave": startTimeout
        }, [genOverlays(false, 'v-snackbar'), slots.default && _createVNode("div", {
          "class": ['v-snackbar__content', props.contentClass],
          "role": "status",
          "aria-live": "polite"
        }, [(_slots$default = slots.default) == null ? void 0 : _slots$default.call(slots)]), slots.actions && _createVNode(VDefaultsProvider, {
          "defaults": {
            VBtn: {
              variant: 'text',
              ripple: false
            }
          }
        }, {
          default: () => [_createVNode("div", {
            "class": "v-snackbar__actions"
          }, [(_slots$actions = slots.actions) == null ? void 0 : _slots$actions.call(slots)])]
        })]), [[_vShow, isActive.value]])]
      })]);
    });
  }

});
//# sourceMappingURL=VSnackbar.mjs.map